From d099a3a526dca18aebd2cf303ebb3662f254ebda Mon Sep 17 00:00:00 2001
From: dongsug-song <35130733+dongsug-song@users.noreply.github.com>
Date: Wed, 15 May 2019 16:43:16 +0900
Subject: [PATCH] [NUI] Change name of VectorAnimationView, Fix VD build error
(#835)
---
...ationView.cs => AnimatedVectorImageView.cs} | 18 +++++++++---------
1 file changed, 9 insertions(+), 9 deletions(-)
rename src/Tizen.NUI/src/public/BaseComponents/{VectorAnimationView.cs => AnimatedVectorImageView.cs} (98%)
diff --git a/src/Tizen.NUI/src/public/BaseComponents/VectorAnimationView.cs b/src/Tizen.NUI/src/public/BaseComponents/AnimatedVectorImageView.cs
similarity index 98%
rename from src/Tizen.NUI/src/public/BaseComponents/VectorAnimationView.cs
rename to src/Tizen.NUI/src/public/BaseComponents/AnimatedVectorImageView.cs
index 6c83565ce..61b1733a2 100755
--- a/src/Tizen.NUI/src/public/BaseComponents/VectorAnimationView.cs
+++ b/src/Tizen.NUI/src/public/BaseComponents/AnimatedVectorImageView.cs
@@ -24,20 +24,20 @@ namespace Tizen.NUI.BaseComponents
using tizenlog = Tizen.Log;
///
/// VectorAnimationView renders an animated vector image
///
/// none
// This will be public opened after ACR done. (Before ACR, need to be hidden as Inhouse API)
[EditorBrowsable(EditorBrowsableState.Never)]
- public class VectorAnimationView : ImageView
+ public class AnimatedVectorImageView : ImageView
{
///
- /// VectorAnimationView constructor
+ /// AnimatedVectorImageView constructor
///
/// none
// This will be public opened after ACR done. (Before ACR, need to be hidden as Inhouse API)
[EditorBrowsable(EditorBrowsableState.Never)]
- public VectorAnimationView()
+ public AnimatedVectorImageView()
{
}
@@ -146,7 +146,7 @@ namespace Tizen.NUI.BaseComponents
}
///
/// The number of times the VectorAnimationView will be looped
///
/// none
// This will be public opened after ACR done. (Before ACR, need to be hidden as Inhouse API)
@@ -308,7 +308,7 @@ namespace Tizen.NUI.BaseComponents
}
///
- /// Play VectorAnimationView
+ /// Play AnimatedVectorImageView
///
/// none
// This will be public opened after ACR done. (Before ACR, need to be hidden as Inhouse API)
@@ -320,7 +320,7 @@ namespace Tizen.NUI.BaseComponents
}
///
- /// Pause VectorAnimationView
+ /// Pause AnimatedVectorImageView
///
/// none
// This will be public opened after ACR done. (Before ACR, need to be hidden as Inhouse API)
@@ -332,7 +332,7 @@ namespace Tizen.NUI.BaseComponents
}
///
- /// Stop VectorAnimationView
+ /// Stop AnimatedVectorImageView
///
/// none
// This will be public opened after ACR done. (Before ACR, need to be hidden as Inhouse API)
@@ -516,7 +516,7 @@ namespace Tizen.NUI.BaseComponents
return ret;
}
- } // VectorAnimationView : ImageView
+ } // AnimatedVectorImageView : ImageView
} // namespace Tizen.NUI.BaseComponents
namespace Tizen.NUI
@@ -24,20 +24,20 @@ namespace Tizen.NUI.BaseComponents
using tizenlog = Tizen.Log;
///
- /// VectorAnimationView renders an animated vector image
+ /// AnimatedVectorImageView renders an animated vector image
///
/// none
@@ -146,7 +146,7 @@ namespace Tizen.NUI.BaseComponents
}
///
- /// The number of times the VectorAnimationView will be looped
+ /// The number of times the AnimatedVectorImageView will be looped
///
/// none
--
2.34.1